SendEditRequest

Struct SendEditRequest 

pub struct SendEditRequest {
    pub name: String,
    pub notes: Option<String>,
    pub view_type: SendViewType,
    pub max_access_count: Option<u32>,
    pub disabled: bool,
    pub hide_email: bool,
    pub deletion_date: DateTime<Utc>,
    pub expiration_date: Option<DateTime<Utc>>,
    pub auth: SendAuthType,
}
Request model for editing an existing Send.

Fields

name: String

The name of the Send.

notes: Option<String>

Optional notes visible to the sender.

view_type: SendViewType

The type and content of the Send.

max_access_count: Option<u32>

Maximum number of times the Send can be accessed.

disabled: bool

Whether the Send is disabled and cannot be accessed.

hide_email: bool

Whether to hide the sender’s email from recipients.

deletion_date: DateTime<Utc>

Date and time when the Send will be permanently deleted.

expiration_date: Option<DateTime<Utc>>

Optional date and time when the Send expires and can no longer be accessed.

auth: SendAuthType

Authentication method for accessing this Send.