struct SendEditRequestWithKey {
request: SendEditRequest,
send_key: String,
}Expand description
Internal helper struct that includes the send key for encryption. The key is retrieved from state during edit operations.
Fields
request: SendEditRequestsend_key: StringTrait Implementations
Sourceimpl CompositeEncryptable<KeyIds, SymmetricKeyId, SendRequestModel> for SendEditRequestWithKey
impl CompositeEncryptable<KeyIds, SymmetricKeyId, SendRequestModel> for SendEditRequestWithKey
Sourcefn encrypt_composite(
&self,
ctx: &mut KeyStoreContext<'_, KeyIds>,
key: SymmetricKeyId,
) -> Result<SendRequestModel, CryptoError>
fn encrypt_composite( &self, ctx: &mut KeyStoreContext<'_, KeyIds>, key: SymmetricKeyId, ) -> Result<SendRequestModel, CryptoError>
⚠️ IMPORTANT NOTE ⚠️ Read more
Sourceimpl Debug for SendEditRequestWithKey
impl Debug for SendEditRequestWithKey
Sourceimpl IdentifyKey<SymmetricKeyId> for SendEditRequestWithKey
impl IdentifyKey<SymmetricKeyId> for SendEditRequestWithKey
fn key_identifier(&self) -> SymmetricKeyId